Ref<T> class

Smart pointer holding a mutable reference to an object.

Get the reference by calling ref() Conveniently, the reference can be reset by setting the ref property.

Constructors

Ref()

Properties

hashCode → int
The hash code for this object.
no setterinherited
ref ↔ T?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

call() → T?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited